| fastcor | R Documentation |
Centers and normalizes rows (or columns when byrow = FALSE) and then
computes Pearson correlations using fast matrix cross-products. This function
does not rank-transform the inputs and therefore does not compute Spearman
correlation.
fastcor(a, b = NULL, byrow = TRUE, diag = TRUE, n.cores = NULL)
a |
Numeric matrix. |
b |
Optional numeric matrix with the same row or column orientation as
|
byrow |
Logical; when |
diag |
Logical; when |
n.cores |
Number of CPU cores requested for the compiled matrix
operations. An explicit value takes precedence over
|
A correlation matrix, or a numeric vector of diagonal correlations when
b is supplied with diag = TRUE.
Stefano Cacciatore, Leonardo Tenori, Dupe Ojo, Alessia Vignoli
pls.single.cv, pls.double.cv
data(iris)
x <- as.matrix(iris[1:10, -5])
fastcor(x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.